@@ -13,7 +13,6 @@ struct gvm_configuration {
 	
 	gboolean autoburn;
 	char *autoburn_audio_cd_command;
-	char *autoburn_photo_cd_command;
 	char *autoburn_data_cd_command;
 	
 	gboolean autoplay_cda;
@@ -49,6 +48,12 @@ struct gvm_configuration {
 	gboolean autovideocam;
 	char *autovideocam_command;
 	
+	gboolean autopilot;
+	char *autopilot_command;
+	
+	gboolean autopocketpc;
+	char *autopocketpc_command;
+	
 	char *eject_command;
 };
 
